@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 12121 2020-04-25 14:18:25Z Trista $
+# $Id: Util.py 12122 2020-04-25 14:24:08Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-25 22:18:25 +0800 (週六, 25 四月 2020) $
-# $Revision: 12121 $
+# $Date: 2020-04-25 22:24:08 +0800 (週六, 25 四月 2020) $
+# $Revision: 12122 $
 """
 Utilities.
 """
@@ -43,7 +43,7 @@ def determinePrintDetail(printDetail, args):
     
     return PrintDetail
 
-def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None, PrintDetail=True):
+def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None, printDetail=True):
     """
     Populate value in environment variables to settings.
 
@@ -60,7 +60,6 @@ def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None, PrintD
     from Iuppiter.Util import colored
     
     args = sys.argv
-    PrintDetail = PrintDetail
     printDetail = determinePrintDetail(printDetail, args)
 
     # if the command is manage.py runserver, then print the SERVER_MODE
