@@ -83,7 +83,7 @@ class GosTest(unittest.TestCase):
         folderId = self._TEST_FOLDER_ID
         result = os.getFiles(folderId)
 
-        self.assertIn(len(result), [3, 4])
+        self.assertIn(len(result), [3, 4, 5])
 
         for file in result:
             if file['name'] == 'plane.jpg':
